#!/usr/bin/env python

"""
RSVP instruction classes.

Copyright (C) 2007 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

class Instruction:

    "A generic instruction."

    def __init__(self, attr=None):
        self.attr = attr

    def __repr__(self):
        return "%s(%r)" % (self.__class__.__name__, self.attr)

# Instructions operating on the value stack.

class LoadConst(Instruction): pass

# Access within an invocation frame.

class LoadName(Instruction): pass
class StoreName(Instruction): pass

# Access to address-relative data.

class MakeObject(Instruction): pass
# ... DropObject not defined: assume garbage collection.
class LoadAttr(Instruction): pass
class StoreAttr(Instruction): pass

# Access to invocation frames in preparation.

class MakeFrame(Instruction): pass
class DropFrame(Instruction): pass
class StoreFrame(Instruction): pass

# Invocation-related instructions.

class Jump(Instruction): pass
class LoadCallable(Instruction): pass
class Return(Instruction): pass

# vim: tabstop=4 expandtab shiftwidth=4
